@@ -1,11 +1,11 @@
-from ._line import Line
-from ._quad import ConstantQuad, Quad
-from ._lagrange import ArbitraryOrderLagrange
 from ._hexahedron import (
     ConstantHexahedron,
     Hexahedron,
     QuadraticHexahedron,
     TriQuadraticHexahedron,
 )
-from ._triangle import Triangle, TriangleMINI, QuadraticTriangle
-from ._tetra import Tetra, TetraMINI, QuadraticTetra
+from ._lagrange import ArbitraryOrderLagrange
+from ._line import Line
+from ._quad import ConstantQuad, Quad
+from ._tetra import QuadraticTetra, Tetra, TetraMINI
+from ._triangle import QuadraticTriangle, Triangle, TriangleMINI
